@@ -1,3 +1,10 @@
+.onAttach <- function(libname, pkgname) {
+  if (!interactive()) return()
+  EGRET_version = utils::packageVersion("EGRET")
+  packageStartupMessage("EGRET ", EGRET_version,"
+Extended Documentation: usgs-r.github.io/EGRET")
+}
+
 #' EGRET package includes WRTDS and flowHistory
 #'
 #' \tabular{ll}{
@@ -16,15 +23,42 @@
 #'  and produce graphs and tables of data and results from these analyses.
 #'
 #' @name EGRET-package
-#' @import utils
-#' @import graphics
-#' @import stats
-#' @import grDevices
 #' @docType package
+#' @importFrom utils write.table
+#' @importFrom utils read.delim
+#' @importFrom utils URLencode
+#' @importFrom utils tail
+#' @importFrom stats aggregate
+#' @importFrom stats lm
+#' @importFrom stats median
+#' @importFrom stats sd
+#' @importFrom stats reshape
+#' @importFrom stats filter
+#' @importFrom stats rnorm
+#' @importFrom stats na.omit
+#' 
+#' @importFrom graphics abline
+#' @importFrom graphics axis
+#' @importFrom graphics box
+#' @importFrom graphics boxplot
+#' @importFrom graphics contour
+#' @importFrom graphics filled.contour
+#' @importFrom graphics grconvertX
+#' @importFrom graphics grconvertY
+#' @importFrom graphics legend
+#' @importFrom graphics lines
+#' @importFrom graphics mtext
+#' @importFrom graphics par
+#' @importFrom graphics points
+#' @importFrom graphics segments
+#' @importFrom graphics title
+#' @importFrom stats predict
+#' @importFrom stats quantile
+#' @importFrom grDevices colorRampPalette
 #' @author Robert M. Hirsch \email{rhirsch@@usgs.gov}, Laura De Cicco \email{ldecicco@@usgs.gov}
 #' @references Hirsch, R.M., and De Cicco, L.A., 2014, User guide to Exploration and Graphics for RivEr Trends 
 #' (EGRET) and dataRetrieval: R packages for hydrologic data: U.S. Geological Survey Techniques and Methods book 4, 
-#' chap. A10, 94 p., \url{https://doi.org/10.3133/tm4A10}
+#' chap. A10, 94 p., \doi{10.3133/tm4A10}
 #' @keywords water-quality graphics streamflow statistics 
 NULL
 
